import React from 'react'
import { get } from 'lodash'
import { Icon, th } from '@pubsweet/ui'
import styled, { css } from 'styled-components'

const AbstractModal = ({ metadata, hideModal }) => (
  <Root>
    <CloseIcon onClick={hideModal}>
      <Icon primary>x</Icon>
    </CloseIcon>
    <Title dangerouslySetInnerHTML={{ __html: get(metadata, 'title') }} />
    <Subtitle>Abstract</Subtitle>
    <Content dangerouslySetInnerHTML={{ __html: get(metadata, 'abstract') }} />
  </Root>
)

export default AbstractModal

// #region styled-components
const defaultText = css`
  color: ${th('colorText')};
  font-family: ${th('fontReading')};
  font-size: ${th('fontSizeBaseSmall')};
`

const Root = styled.div`
  background-color: ${th('backgroundColor')};
  border: ${th('borderDefault')};
  max-height: 500px;
  padding: ${th('gridUnit')};
  padding-top: calc(${th('gridUnit')} * 2);
  position: relative;
  overflow-y: scroll;
  width: 600px;
`

const Title = styled.div`
  ${defaultText};
  font-size: ${th('fontSizeBase')};
  text-align: left;
`

const Subtitle = styled.div`
  ${defaultText};
  font-weight: bold;
  line-height: 1.57;
  margin-bottom: ${th('subGridUnit')};
  text-align: left;
`

const Content = styled.div`
  ${defaultText};
  line-height: 1.57;
  margin-top: calc(${th('subGridUnit')} * 2);
  text-align: left;
`

const CloseIcon = styled.div`
  cursor: pointer;
  position: absolute;
  top: ${th('subGridUnit')};
  right: ${th('subGridUnit')};
`
// #endregion
